@@ -1,6 +1,6 @@
 package Bundle::OpenXPKI;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 1;
 __END__
@@ -141,6 +141,8 @@ Cwd 3.12
 
 CPAN 1.76_02
 
+Data::Serializer 0.44
+
 DBD::ExampleP 12.009153
 
 DBD::File 0.35
@@ -293,12 +295,12 @@ Date::Language::TigrinyaEritrean 1.00
 
 Date::Language::TigrinyaEthiopian 1.00
 
-Date::Parse 2.27
-
 DateTime 0.36
 
 DateTime::Duration undef
 
+DateTime::Format::DateParse 0.04
+
 DateTime::Format::Strptime 1.0700
 
 DateTime::Helpers undef
